@@ -3,6 +3,8 @@ package Config::Any::XML;
 use strict;
 use warnings;
 
+use base 'Config::Any::Base';
+
 =head1 NAME
 
 Config::Any::XML - Load XML config files
@@ -55,14 +57,13 @@ sub load {
 }
 
 sub _coerce {
-
     # coerce the XML-parsed config into the correct format
     my $class  = shift;
     my $config = shift;
     my $out;
     for my $k ( keys %$config ) {
         my $ref = $config->{ $k };
-        my $name = ref $ref ? delete $ref->{ name } : undef;
+        my $name = ref $ref eq 'HASH' ? delete $ref->{ name } : undef;
         if ( defined $name ) {
             $out->{ $k }->{ $name } = $ref;
         }
@@ -73,16 +74,13 @@ sub _coerce {
     $out;
 }
 
-=head2 is_supported( )
+=head2 requires_all_of( )
 
-Returns true if L<XML::Simple> is available.
+Specifies that this module requires L<XML::Simple> in order to work.
 
 =cut
 
-sub is_supported {
-    eval { require XML::Simple; };
-    return $@ ? 0 : 1;
-}
+sub requires_all_of { 'XML::Simple' }
 
 =head1 CAVEATS
 
@@ -103,7 +101,7 @@ Joel Bernstein E<lt>rataxis@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Brian Cassidy
+Copyright 2006-2009 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
